(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0e57b0"],{9553:function(n,e,l){"use strict";l.r(e);var t=function(){var n=this,e=n.$createElement,l=n._self._c||e;return l("div",[n._v("\n  Hello, Index\n")])},u=[],o=l("2877"),c={},i=Object(o["a"])(c,t,u,!1,null,null,null);i.options.__file="Index.vue";e["default"]=i.exports}}]);
//# sourceMappingURL=chunk-2d0e57b0.f767aba8.js.map