(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-4e3d1917"],{bddd:function(n,t,e){"use strict";e.r(t);var r=function(){var n=this,t=n.$createElement,e=n._self._c||t;return e("div",[e("b-table",{attrs:{responsive:"",striped:"",hover:"",items:n.emails,fields:n.fields},scopedSlots:n._u([{key:"time",fn:function(t){return[n._v("\r\n      "+n._s(n.$formatTime(t.value))+"\r\n    ")]}}])}),e("b-pagination",{attrs:{align:"center",size:"md",limit:10,"total-rows":n.totalItems,"per-page":n.itemsPerPage},on:{change:function(t){n.refresh(t)}},model:{value:n.currentPage,callback:function(t){n.currentPage=t},expression:"currentPage"}})],1)},a=[],i=e("be6c"),u={name:"adminEmail",data:function(){return{emails:[],fields:[{key:"id",sortable:!0},{key:"to",sortable:!0},{key:"subject"},{key:"remark"},{key:"type"},{key:"content"},{key:"time"},{key:"action",label:"Action"}],currentPage:1,itemsPerPage:20,totalItems:0}},methods:{refresh:function(n){var t=this;void 0===n&&(n=this.currentPage),Object(i["k"])({page:n,perPage:this.itemsPerPage}).then(function(n){t.totalItems=n.emails.total,t.emails=n.emails.items})}},created:function(){this.refresh()}},c=u,o=e("2877"),d=Object(o["a"])(c,r,a,!1,null,null,null);d.options.__file="Email.vue";t["default"]=d.exports},be6c:function(n,t,e){"use strict";e.d(t,"f",function(){return a}),e.d(t,"m",function(){return i}),e.d(t,"s",function(){return u}),e.d(t,"t",function(){return c}),e.d(t,"c",function(){return o}),e.d(t,"h",function(){return d}),e.d(t,"n",function(){return f}),e.d(t,"e",function(){return s}),e.d(t,"d",function(){return l}),e.d(t,"l",function(){return m}),e.d(t,"g",function(){return p}),e.d(t,"k",function(){return b}),e.d(t,"j",function(){return g}),e.d(t,"o",function(){return j}),e.d(t,"r",function(){return O}),e.d(t,"q",function(){return k}),e.d(t,"p",function(){return h}),e.d(t,"u",function(){return P}),e.d(t,"a",function(){return v}),e.d(t,"i",function(){return y}),e.d(t,"b",function(){return w});e("cadf"),e("551c"),e("097d");var r=e("4182"),a=function(n){return Object(r["a"])("/api/admin/product/getAll",n)},i=function(n){return Object(r["a"])("/api/admin/product/get",n)},u=function(n){return Object(r["a"])("/api/admin/product/update",n)},c=function(n){return Object(r["a"])("/api/admin/productQrcode/update",n)},o=function(n){return Object(r["a"])("/api/admin/productQrcode/delete",n)},d=function(n){return Object(r["a"])("/api/admin/user/getAll",n)},f=function(n){return Object(r["a"])("/api/admin/user/getDetail",n)},s=function(n){return Object(r["a"])("/api/admin/account/get",n)},l=function(n){return Object(r["a"])("/api/admin/account/getDetail",n)},m=function(n){return Object(r["a"])("/api/admin/orderHistory/get",n)},p=function(n){return Object(r["a"])("/api/admin/setting/getAll",n)},b=function(n){return Object(r["a"])("/api/admin/email/getPage",n)},g=function(n){return Object(r["a"])("/api/admin/flowUsage/getInDay",n)},j=function(n){return Object(r["a"])("/api/admin/account/randomPassword",n)},O=function(n){return Object(r["a"])("/api/admin/account/updatePassword",n)},k=function(n){return Object(r["a"])("/api/admin/account/updateTotalFlow",n)},h=function(n){return Object(r["a"])("/api/admin/account/updateExpiration",n)},P=function(n){return Object(r["a"])("/api/admin/user/updateInfo",n)},v=function(n){return Object(r["a"])("/api/admin/announcement/create",n)},y=function(n){return Object(r["a"])("/api/admin/announcement/getAll",n)},w=function(n){return Object(r["a"])("/api/admin/announcement/delete",n)}}}]);
//# sourceMappingURL=chunk-4e3d1917.ce371e9b.js.map