(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-4fae7c5f"],{be6c:function(e,t,n){"use strict";n.d(t,"f",function(){return a}),n.d(t,"m",function(){return i}),n.d(t,"s",function(){return u}),n.d(t,"t",function(){return c}),n.d(t,"c",function(){return o}),n.d(t,"h",function(){return d}),n.d(t,"n",function(){return f}),n.d(t,"e",function(){return s}),n.d(t,"d",function(){return p}),n.d(t,"l",function(){return l}),n.d(t,"g",function(){return m}),n.d(t,"k",function(){return b}),n.d(t,"j",function(){return g}),n.d(t,"o",function(){return O}),n.d(t,"r",function(){return j}),n.d(t,"q",function(){return y}),n.d(t,"p",function(){return h}),n.d(t,"u",function(){return k}),n.d(t,"a",function(){return P}),n.d(t,"i",function(){return v}),n.d(t,"b",function(){return _});n("cadf"),n("551c"),n("097d");var r=n("4182"),a=function(e){return Object(r["a"])("/api/admin/product/getAll",e)},i=function(e){return Object(r["a"])("/api/admin/product/get",e)},u=function(e){return Object(r["a"])("/api/admin/product/update",e)},c=function(e){return Object(r["a"])("/api/admin/productQrcode/update",e)},o=function(e){return Object(r["a"])("/api/admin/productQrcode/delete",e)},d=function(e){return Object(r["a"])("/api/admin/user/getAll",e)},f=function(e){return Object(r["a"])("/api/admin/user/getDetail",e)},s=function(e){return Object(r["a"])("/api/admin/account/get",e)},p=function(e){return Object(r["a"])("/api/admin/account/getDetail",e)},l=function(e){return Object(r["a"])("/api/admin/orderHistory/get",e)},m=function(e){return Object(r["a"])("/api/admin/setting/getAll",e)},b=function(e){return Object(r["a"])("/api/admin/email/getPage",e)},g=function(e){return Object(r["a"])("/api/admin/flowUsage/getInDay",e)},O=function(e){return Object(r["a"])("/api/admin/account/randomPassword",e)},j=function(e){return Object(r["a"])("/api/admin/account/updatePassword",e)},y=function(e){return Object(r["a"])("/api/admin/account/updateTotalFlow",e)},h=function(e){return Object(r["a"])("/api/admin/account/updateExpiration",e)},k=function(e){return Object(r["a"])("/api/admin/user/updateInfo",e)},P=function(e){return Object(r["a"])("/api/admin/announcement/create",e)},v=function(e){return Object(r["a"])("/api/admin/announcement/getAll",e)},_=function(e){return Object(r["a"])("/api/admin/announcement/delete",e)}},c19e:function(e,t,n){"use strict";n.r(t);var r=function(){var e=this,t=e.$createElement,n=e._self._c||t;return n("div",{staticClass:"table-responsive"},[n("b-table",{attrs:{responsive:"",striped:"",hover:"",items:e.orders,fields:e.fields},scopedSlots:e._u([{key:"time",fn:function(t){return[e._v("\r\n      "+e._s(e.$formatTime(t.value))+"\r\n    ")]}},{key:"user",fn:function(t){return[e._v("\r\n      "+e._s(t.item.uid)+"\r\n    ")]}},{key:"pay",fn:function(t){return[t.item.alipay?n("span",[e._v(e._s("Alipay: "+e.o.alipay))]):e._e(),t.item.wechatpay?n("span",[e._v(e._s("WechatPay: "+e.o.wechatpay))]):e._e()]}}])}),n("b-pagination",{attrs:{align:"center",size:"md",limit:10,"total-rows":e.totalOrders,"per-page":e.itemsPerPage},on:{change:function(t){e.refresh(t)}},model:{value:e.currentPage,callback:function(t){e.currentPage=t},expression:"currentPage"}})],1)},a=[],i=n("be6c"),u={name:"adminOrder",data:function(){return{orders:[],fields:[{key:"id",sortable:!0},{key:"pid",sortable:!0},{key:"user",label:"user"},{key:"code"},{key:"pay",label:"支付方式"},{key:"orderTime",formatter:this.$formatTime},{key:"bufferPeriodExpire",formatter:this.$formatTime},{key:"expire",formatter:this.$formatTime},{key:"action",label:"Action"}],currentPage:1,itemsPerPage:20,totalOrders:0}},computed:{},methods:{refresh:function(e){var t=this;void 0===e&&(e=this.currentPage),Object(i["l"])({page:e,perPage:this.itemsPerPage}).then(function(e){t.totalOrders=e.orders.total,t.orders=e.orders.items})}},created:function(){this.refresh()}},c=u,o=n("2877"),d=Object(o["a"])(c,r,a,!1,null,null,null);d.options.__file="Order.vue";t["default"]=d.exports}}]);
//# sourceMappingURL=chunk-4fae7c5f.fa6a02cc.js.map