(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-4eb96bb6"],{2927:function(t,e,n){},"546c":function(t,e,n){"use strict";var r=n("2927"),i=n.n(r);i.a},"9f17":function(t,e,n){"use strict";n.r(e);var r=function(){var t=this,e=t.$createElement,n=t._self._c||e;return n("div",t._l(t.cardItems,function(e,r){return n("b-card",{key:r,staticClass:"my-2 text-center"},[n("router-link",{staticClass:"h3",attrs:{to:e.to}},[t._v(t._s(e.title))])],1)}),1)},i=[],s={name:"adminHistory",data:function(){return{cardItems:[{to:"/history/order",title:"历史订单"},{to:"/history/email",title:"历史邮件"}]}}},o=s,a=(n("546c"),n("2877")),c=Object(a["a"])(o,r,i,!1,null,null,null);c.options.__file="History.vue";e["default"]=c.exports}}]);
//# sourceMappingURL=chunk-4eb96bb6.271e5176.js.map