(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-27d07130"],{1602:function(t,s,a){"use strict";a.d(s,"h",function(){return o}),a.d(s,"j",function(){return r}),a.d(s,"i",function(){return n}),a.d(s,"d",function(){return i}),a.d(s,"a",function(){return c}),a.d(s,"g",function(){return d}),a.d(s,"e",function(){return l}),a.d(s,"c",function(){return u}),a.d(s,"b",function(){return p}),a.d(s,"f",function(){return f});var e=a("4182"),o=function(t){return Object(e["a"])("/api/user/accountDetail",t)},r=function(t){return Object(e["a"])("/api/user/updatePassword",t)},n=function(t){return Object(e["a"])("/api/user/account/updatePassword",t)},i=function(t){return Object(e["a"])("/api/user/product/getAll",t)},c=function(t){return Object(e["a"])("/api/user/product/canPlace",t)},d=function(t){return Object(e["a"])("/api/user/product/getDetail",t)},l=function(t){return Object(e["a"])("/api/user/flowUsage/getInDay",t)},u=function(t){return Object(e["a"])("/api/user/announcement/getAll",t)},p=function(t){return Object(e["a"])("/api/user/product/confirm",t)},f=function(t){return Object(e["a"])("/api/user/orderHistory/get",t)}},e0da:function(t,s,a){"use strict";a.r(s);var e=function(){var t=this,s=t.$createElement,a=t._self._c||s;return a("div",[a("b-card",[a("div",{staticClass:"row"},[a("div",{staticClass:"col-12 col-sm-8"},[a("div",{staticClass:"row border-bottom py-2"},[a("div",{staticClass:"col-12 col-sm-6 text-left text-md"},[a("text-input",{attrs:{"input-prop":{title:"Host",icon:"fas fa-network-wired"},readonly:!0},model:{value:t.ad.server,callback:function(s){t.$set(t.ad,"server",s)},expression:"ad.server"}})],1),a("div",{staticClass:"col-12 col-sm-6 text-left text-md"},[a("text-input",{attrs:{"input-prop":{title:"Port",icon:"fas fa-ethernet"},readonly:!0},model:{value:t.ad.port,callback:function(s){t.$set(t.ad,"port",s)},expression:"ad.port"}})],1)]),a("div",{staticClass:"row py-2"},[a("div",{staticClass:"col-12 col-sm-6 text-left text-md"},[a("text-input",{attrs:{"input-prop":{title:"Password",icon:"fas fa-key"}},on:{valueChanged:function(s){t.isPasswordChanged=!0}},model:{value:t.ad.password,callback:function(s){t.$set(t.ad,"password",s)},expression:"ad.password"}}),a("button",{staticClass:"btn btn-primary mx-3",attrs:{type:"button",disabled:!t.isPasswordChanged},on:{click:function(s){t.updatePassword()}}},[t._v(t._s("Update"))])],1),a("div",{staticClass:"col-12 col-sm-6 text-left text-md"},[a("text-input",{attrs:{"input-prop":{title:"TotalFlow",icon:"fas fa-globe"},readonly:!0,value:t.totalFlow.toFixed(0)+" GB"}}),a("span",[t._v(t._s("FlowUsage:"))]),a("b-progress",{staticClass:"mb-3",attrs:{max:t.totalFlow,"show-value":"",precision:1}},[a("b-progress-bar",{attrs:{value:t.$convertFlow(t.ad.usedFlow,"GB"),variant:"primary"}}),a("b-progress-bar",{attrs:{value:t.totalFlow-t.$convertFlow(t.ad.usedFlow,"GB"),variant:"success"}})],1)],1)])]),a("div",{staticClass:"col-12 col-sm-4 text-center"},[a("b-alert",{attrs:{variant:"primary",show:""}},[t._v("\r\n          使用 shadowsocks 手机客户端的“扫一扫”导入配置\r\n        ")]),a("qrcode-vue",{staticClass:"d-inline-block mx-auto",attrs:{value:t.ssAddress,size:200,level:"H"}})],1)])]),a("b-card",[a("div",{staticClass:"border-bottom my-2"},[a("div",{staticClass:"row pb-2"},[a("span",{staticClass:"col-4 text-left text-lg"},[t._v(t._s("Expire:"))]),a("span",{staticClass:"col-8 text-left text-md"},[t._v(t._s(t.$formatTime(t.ad.expire)))])])]),a("div",{staticClass:"row border-bottom my-2"},[a("span",{staticClass:"col-4 text-left text-lg"},[t._v(t._s("Status:")+" ")]),a("span",{staticClass:"col-4 text-left text-md"},[t._v(t._s(t.ad.status))])]),a("div",{staticClass:"row border-bottom my-2"},[a("span",{staticClass:"col-4 text-left text-lg"},[t._v(t._s("Create Time:")+" ")]),a("span",{staticClass:"col-8 text-left text-md"},[t._v(t._s(t.$formatTime(t.ad.createTime)))])]),t.ad.userId?a("div",{staticClass:"row my-2"},[a("span",{staticClass:"col-4 text-left text-lg"},[t._v(t._s("Last Connected:")+" ")]),a("span",{staticClass:"col-8 text-left text-md"},[t._v(t._s(t.$formatTime(t.ad.updateTime)))])]):t._e()]),a("b-modal",{attrs:{"ok-only":!0,title:"修改密码状态"},model:{value:t.modifyPasswordModal,callback:function(s){t.modifyPasswordModal=s},expression:"modifyPasswordModal"}},[t._v("\r\n    修改成功\r\n  ")])],1)},o=[],r=(a("cadf"),a("551c"),a("097d"),a("446e")),n=a("1602"),i=a("d7b0"),c=1073741824,d={name:"userIndex",components:{TextInput:r["a"],QrcodeVue:i["a"]},data:function(){return{ad:{},ssAddress:"",isPasswordChanged:!1,modifyPasswordModal:!1}},methods:{updatePassword:function(t){var s=this;Object(n["i"])({password:this.ad.password}).then(function(t){s.modifyPasswordModal=!0,s.isPasswordChanged=!1})}},computed:{totalFlow:function(){return this.ad.totalFlow/c}},created:function(){var t=this;Object(n["h"])().then(function(s){t.ad=s.account,t.ssAddress="ss://"+btoa(s.ssAddress)})}},l=d,u=a("2877"),p=Object(u["a"])(l,e,o,!1,null,null,null);p.options.__file="Account.vue";s["default"]=p.exports}}]);
//# sourceMappingURL=chunk-27d07130.c917c23d.js.map