(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0ae4f0"],{"0a09":function(t,e,n){"use strict";n.r(e);var s=function(){var t=this,e=t.$createElement,n=t._self._c||e;return n("div",[n("b-button",{attrs:{variant:"success"},on:{click:function(e){t.redirectAsUser()}}},[t._v("普通用户视角")]),n("b-card",{staticClass:"my-1",attrs:{title:"总览"}})],1)},c=[],i={name:"adminIndex",methods:{redirectAsUser:function(){window.location="/user"}}},a=i,r=n("2877"),o=Object(r["a"])(a,s,c,!1,null,null,null);o.options.__file="Index.vue";e["default"]=o.exports}}]);
//# sourceMappingURL=chunk-2d0ae4f0.12788d59.js.map