.text-sm,.text-sm span{font-size:16px}.text-md,.text-md span{font-size:20px}.text-lg,.text-lg span{font-size:24px}.dimmer .loader{display:none;margin:0 auto;position:absolute;top:50%;left:0;right:0;-webkit-transform:translateY(-50%);transform:translateY(-50%)}.loader{display:block;position:relative;height:2.5rem;width:2.5rem;color:#467fcf}.nav-link{cursor:pointer}.h-100{height:100%!important}.sidebar{background-color:#f5f5f5;padding-right:20px;padding-top:20px;min-height:calc(95vh - 30px)}@media screen and (max-width:768px){.sidebar{padding-top:15px;padding-right:15px;position:fixed;z-index:1000}}