.custom-switch{-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;cursor:default;display:-ms-inline-flexbox;display:-webkit-inline-box;display:inline-flex;-ms-flex-align:center;-webkit-box-align:center;align-items:center;margin:0}.custom-switch-input{position:absolute;z-index:-1;opacity:0}.custom-switch-indicator{display:inline-block;height:1.25rem;width:2.25rem;background:#e9ecef;border-radius:50px;position:relative;vertical-align:bottom;border:1px solid rgba(0,40,100,.12);-webkit-transition:border-color .3s,background-color .3s;transition:border-color .3s,background-color .3s}input[type=checkbox],input[type=radio]{-webkit-box-sizing:border-box;box-sizing:border-box;padding:0}