.form-signup{width:450px;max-width:450px;padding:15px;margin:0 auto}.form-signup .checkbox{font-weight:400}.form-signup .form-control{position:relative;-webkit-box-sizing:border-box;box-sizing:border-box;height:auto;padding:10px;font-size:16px}.form-signup .form-control:focus{z-index:2}.form-signup input[type=email]{margin-bottom:-1px;border-bottom-right-radius:0;border-bottom-left-radius:0}.form-signup input[type=password]{margin-bottom:10px;border-top-left-radius:0;border-top-right-radius:0}