.text-sm,.text-sm span{font-size:16px}.text-md,.text-md span{font-size:20px}.text-lg,.text-lg span{font-size:24px}.dimmer .loader{display:none;margin:0 auto;position:absolute;top:50%;left:0;right:0;-webkit-transform:translateY(-50%);transform:translateY(-50%)}.loader{display:block;height:2.5rem;width:2.5rem;color:#467fcf}.loader,body{position:relative}body{direction:ltr;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;-webkit-tap-highlight-color:transparent;-webkit-text-size-adjust:none;-ms-touch-action:manipulation;touch-action:manipulation;-webkit-font-feature-settings:"liga" 0;font-feature-settings:"liga" 0;height:100%;overflow-y:scroll;background-color:#f0f0f0}.page{margin-top:20px;display:-ms-flexbox;display:-webkit-box;display:flex;-ms-flex-direction:column;-webkit-box-orient:vertical;-webkit-box-direction:normal;flex-direction:column;-ms-flex-pack:center;-webkit-box-pack:center;justify-content:center;min-height:100%}