(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-5d49c948"],{be6c:function(n,t,e){"use strict";e.d(t,"f",function(){return u}),e.d(t,"m",function(){return i}),e.d(t,"s",function(){return a}),e.d(t,"t",function(){return c}),e.d(t,"c",function(){return o}),e.d(t,"h",function(){return d}),e.d(t,"n",function(){return f}),e.d(t,"e",function(){return s}),e.d(t,"d",function(){return l}),e.d(t,"l",function(){return p}),e.d(t,"g",function(){return m}),e.d(t,"k",function(){return b}),e.d(t,"j",function(){return j}),e.d(t,"o",function(){return O}),e.d(t,"r",function(){return v}),e.d(t,"q",function(){return g}),e.d(t,"p",function(){return k}),e.d(t,"u",function(){return w}),e.d(t,"a",function(){return y}),e.d(t,"i",function(){return h}),e.d(t,"b",function(){return _});e("cadf"),e("551c"),e("097d");var r=e("4182"),u=function(n){return Object(r["a"])("/api/admin/product/getAll",n)},i=function(n){return Object(r["a"])("/api/admin/product/get",n)},a=function(n){return Object(r["a"])("/api/admin/product/update",n)},c=function(n){return Object(r["a"])("/api/admin/productQrcode/update",n)},o=function(n){return Object(r["a"])("/api/admin/productQrcode/delete",n)},d=function(n){return Object(r["a"])("/api/admin/user/getAll",n)},f=function(n){return Object(r["a"])("/api/admin/user/getDetail",n)},s=function(n){return Object(r["a"])("/api/admin/account/get",n)},l=function(n){return Object(r["a"])("/api/admin/account/getDetail",n)},p=function(n){return Object(r["a"])("/api/admin/orderHistory/get",n)},m=function(n){return Object(r["a"])("/api/admin/setting/getAll",n)},b=function(n){return Object(r["a"])("/api/admin/email/getPage",n)},j=function(n){return Object(r["a"])("/api/admin/flowUsage/getInDay",n)},O=function(n){return Object(r["a"])("/api/admin/account/randomPassword",n)},v=function(n){return Object(r["a"])("/api/admin/account/updatePassword",n)},g=function(n){return Object(r["a"])("/api/admin/account/updateTotalFlow",n)},k=function(n){return Object(r["a"])("/api/admin/account/updateExpiration",n)},w=function(n){return Object(r["a"])("/api/admin/user/updateInfo",n)},y=function(n){return Object(r["a"])("/api/admin/announcement/create",n)},h=function(n){return Object(r["a"])("/api/admin/announcement/getAll",n)},_=function(n){return Object(r["a"])("/api/admin/announcement/delete",n)}},de51:function(n,t,e){"use strict";e.r(t);var r=function(){var n=this,t=n.$createElement,e=n._self._c||t;return e("div",{staticClass:"table-responsive"},[e("b-table",{attrs:{striped:"",hoverd:"",items:n.users,fields:n.fields},scopedSlots:n._u([{key:"flow",fn:function(t){return[n._v("\r\n      "+n._s(n.$formatFlow(t.value,"MB"))+"\r\n    ")]}},{key:"price",fn:function(t){return[n._v("\r\n      ￥"+n._s(t.value)+"\r\n    ")]}},{key:"action",fn:function(t){return[e("b-button",{attrs:{variant:"primary"},on:{click:function(e){n.viewDetail(t.item.id)}}},[n._v("操作")])]}}])})],1)},u=[],i=e("be6c"),a={name:"adminUser",data:function(){return{users:[],fields:[{key:"id",label:"User ID"},{key:"email",label:"邮箱"},{key:"type",label:"类型"},{key:"comment",label:"备注"},{key:"username",label:"用户名"},{key:"createTime",label:"创建日期",formatter:this.$formatTime},{key:"action",label:"操作"}]}},methods:{viewDetail:function(n){this.$router.push({name:"userDetail",path:"/user",params:{id:n}})}},created:function(){var n=this;Object(i["h"])().then(function(t){n.users=t.users})}},c=a,o=e("2877"),d=Object(o["a"])(c,r,u,!1,null,null,null);d.options.__file="User.vue";t["default"]=d.exports}}]);
//# sourceMappingURL=chunk-5d49c948.aedba938.js.map